/*====================================================================

ObjectWeb Deployment Framework
Copyright (C) 2004-2006 INRIA - USTL - LIFL - GOAL
Contact: deployment@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Philippe Merle, Frdric Briclet.
Contributor(s): Eric Bruneton.

====================================================================
$Id: ConfigurationTask.java,v 1.2 2006/02/16 18:13:18 merle Exp $
====================================================================*/

package org.objectweb.deployment.scheduling.component.api;

/**
 * ConfigurationTask is the base interface of any deployment task
 * which configures a component instance feature.
 *
 * ConfigurationTask extends RequireInstanceProviderTask
 * because a component instance provider task is required.
 *
 * @author <a href="mailto:Philippe.Merle@inria.fr">Philippe Merle</a>
 * @author <a href="mailto:Frdric.Briclet@lifl.fr">Frdric Briclet</a>
 *
 * @version 0.2
 */

public interface ConfigurationTask
         extends RequireInstanceProviderTask
{
    /**
     * Return the component feature name to configure.
     *
     * @return The component feature name to configure.
     */
    public String
    getFeatureName();

    /**
     * Set the component feature name to configure.
     *
     * @param name - The component feature name to configure.
     */
    public void
    setFeatureName(String name);
}
